use strict;
use version 0.77;

package Alien::Font::Uni;
our $VERSION = '0.3';

sub get_path { '/usr/share/fonts/unifont/unifont.ttf' }

sub font_version {
    open(my $f, '<', get_path()) or return undef;
    local $/ = undef;
    my $content = <$f>;
    close($f) or return undef;
    return "$1" if $content =~ m{Version\s+(\d+(?:\.\d+)*)};
    return undef;
}
sub font_vstring {
    return version->parse(font_version())->normal;
}

1;

__END__

=pod

=head1 NAME

Alien::Font::Uni - access to Unifont truetype file

=head1 SYNOPSIS 

    use Alien::Font::Uni;
    
    my $path = Alien::Font::Uni::get_path();
    my $vstring = Alien::Font::Uni::font_vstring();
    my $string  = Alien::Font::Uni::font_version();

=head1 DESCRIPTION

This module was created as an optional dependency of L<Chart>
to have access to an unicode complete scaleable font file. 
Thus only the .ttf file is provided since this is what L<GD> can read.
Distros might redirect to pre-existing resources.

=head1 FONT

Unifont 15, Copyright(c) 1998 - 2022 by Roman Czyborra, Paul Hardy
and contributors - Licensed under OFL 1.1

=head1 AUTHOR

Herbert Breunung (lichtkind@cpan.org)

=head1 COPYRIGHT

Copyright(c) 2022 by Herbert Breunung

All rights reserved. This program is free software; you can
redistribute it and/or modify it under the same terms as Perl 
itself.

=cut

